From 3f9c1f55d76a38fc24b4582a4a154ea3bb951a03 Mon Sep 17 00:00:00 2001
From: Andreas Dannenberg <dannenberg@ti.com>
Date: Mon, 27 Mar 2023 18:44:53 -0500
Subject: [PATCH] am62xx-evm: Make AM62x GP device variant the default (from
 HS-FS)

In order to allow directly booting existing AM62x boards that are
populated with the "GP" device variant re-configure the multi-config
based image generation process to generate a GP-device compatible
tiboot3.bin initial boot binary by default, this way enabling booting
GP-device based boards without having to manually rename/update the
tiboot3.bin file to match those boards after each and every build.

Signed-off-by: Andreas Dannenberg <dannenberg@ti.com>
---
 conf/machine/am62xx-evm-k3r5-gp.conf    |  7 -------
 conf/machine/am62xx-evm-k3r5-hs-fs.conf |  7 +++++++
 conf/machine/include/am62xx.inc         | 20 ++++++++++----------
 3 files changed, 17 insertions(+), 17 deletions(-)

diff --git a/conf/machine/am62xx-evm-k3r5-gp.conf b/conf/machine/am62xx-evm-k3r5-gp.conf
index ab18301a..724a8d4a 100644
--- a/conf/machine/am62xx-evm-k3r5-gp.conf
+++ b/conf/machine/am62xx-evm-k3r5-gp.conf
@@ -8,11 +8,4 @@ SYSFW_SOC = "am62x"
 SYSFW_CONFIG = "evm"
 SYSFW_SUFFIX = "gp"
 
-SYSFW_TIBOOT3_SYMLINK = ""
-
 UBOOT_MACHINE = "am62x_evm_r5_defconfig"
-
-SPL_BINARY = ""
-UBOOT_BINARY = "u-boot-spl.${UBOOT_SUFFIX}"
-UBOOT_IMAGE = "u-boot-r5spl-gp-${MAINMACHINE}-${PV}-${PR}.${UBOOT_SUFFIX}"
-UBOOT_SYMLINK = "u-boot-r5spl-gp.${UBOOT_SUFFIX}"
diff --git a/conf/machine/am62xx-evm-k3r5-hs-fs.conf b/conf/machine/am62xx-evm-k3r5-hs-fs.conf
index 0f016547..5cafdd06 100644
--- a/conf/machine/am62xx-evm-k3r5-hs-fs.conf
+++ b/conf/machine/am62xx-evm-k3r5-hs-fs.conf
@@ -11,4 +11,11 @@ SYSFW_SOC = "am62x"
 SYSFW_CONFIG = "evm"
 SYSFW_SUFFIX = "hs-fs"
 
+SYSFW_TIBOOT3_SYMLINK = ""
+
 UBOOT_MACHINE = "am62x_evm_r5_defconfig"
+
+SPL_BINARY = ""
+UBOOT_BINARY = "u-boot-spl.${UBOOT_SUFFIX}"
+UBOOT_IMAGE = "u-boot-r5spl-hs-fs-${MAINMACHINE}-${PV}-${PR}.${UBOOT_SUFFIX}"
+UBOOT_SYMLINK = "u-boot-r5spl-hs-fs.${UBOOT_SUFFIX}"
diff --git a/conf/machine/include/am62xx.inc b/conf/machine/include/am62xx.inc
index 6b2c0da3..01afd5c9 100644
--- a/conf/machine/include/am62xx.inc
+++ b/conf/machine/include/am62xx.inc
@@ -8,18 +8,18 @@ SERIAL_CONSOLES_CHECK = "${SERIAL_CONSOLES}"
 
 TFA_K3_SYSTEM_SUSPEND = "1"
 
-# Default tiboot3.bin on AM62x is for HS-FS
-BBMULTICONFIG = "k3r5-hs-fs"
-do_image_wic[mcdepends] = "mc::k3r5-hs-fs:ti-sci-fw:do_deploy"
-do_image_tar[mcdepends] = "mc::k3r5-hs-fs:ti-sci-fw:do_deploy"
+# Default tiboot3.bin on AM62x is for GP
+BBMULTICONFIG = "k3r5-gp"
+do_image_wic[mcdepends] = "mc::k3r5-gp:ti-sci-fw:do_deploy"
+do_image_tar[mcdepends] = "mc::k3r5-gp:ti-sci-fw:do_deploy"
 
-# Since default tiboot3.bin on AM62x is for HS-FS, add a version for GP
-BBMULTICONFIG += "k3r5-gp"
-IMAGE_BOOT_FILES += " tiboot3-am62x-gp-evm.bin"
-do_image_wic[mcdepends] += "mc::k3r5-gp:ti-sci-fw:do_deploy"
-do_image_tar[mcdepends] += "mc::k3r5-gp:ti-sci-fw:do_deploy"
+# Since default tiboot3.bin on AM62x is for GP, add a version for HS-FS
+BBMULTICONFIG += "k3r5-hs-fs"
+IMAGE_BOOT_FILES += " tiboot3-am62x-hs-fs-evm.bin"
+do_image_wic[mcdepends] += "mc::k3r5-hs-fs:ti-sci-fw:do_deploy"
+do_image_tar[mcdepends] += "mc::k3r5-hs-fs:ti-sci-fw:do_deploy"
 
-# Since default tiboot3.bin on AM62x is for HS-FS, add a version for HS-SE
+# Since default tiboot3.bin on AM62x is for GP, add a version for HS-SE
 BBMULTICONFIG += "k3r5-hs-se"
 IMAGE_BOOT_FILES += " tiboot3-am62x-hs-evm.bin"
 do_image_wic[mcdepends] += "mc::k3r5-hs-se:ti-sci-fw:do_deploy"
-- 
2.34.1

